<?php
/**
 * @package Helix Ultimate Framework
 * @author Unitemplates https://www.unitemplates.com
 * @copyright Copyright (c) 2010 - 2021 Unitemplates
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or Later
*/

defined ('_JEXEC') or die();

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Layout\FileLayout;
use Joomla\CMS\Uri\Uri;

HTMLHelper::addIncludePath(JPATH_COMPONENT . '/helpers');

$app = Factory::getApplication();

$this->category->text = $this->category->description;
$app->triggerEvent('onContentPrepare', array($this->category->extension . '.categories', &$this->category, &$this->params, 0));
$this->category->description = $this->category->text;

$results = $app->triggerEvent('onContentAfterTitle', array($this->category->extension . '.categories', &$this->category, &$this->params, 0));
$afterDisplayTitle = trim(implode("\n", $results));

$results = $app->triggerEvent('onContentBeforeDisplay', array($this->category->extension . '.categories', &$this->category, &$this->params, 0));
$beforeDisplayContent = trim(implode("\n", $results));

$results = $app->triggerEvent('onContentAfterDisplay', array($this->category->extension . '.categories', &$this->category, &$this->params, 0));
$afterDisplayContent = trim(implode("\n", $results));

// Unitemplates
// Custom Blog Layouts
$doc = Factory::getDocument();
$template_name = JFactory::getApplication()->getTemplate();
$masonry = $this->params->get('ublog_masonry', 0);

$columns = ($this->params->get('num_columns')) ? ' col-xl-'.round(12 / $this->params->get('num_columns')) : '';
$columns .= ($this->params->get('columns_lg')) ? ' col-lg-'.round(12 / $this->params->get('columns_lg')) : '';
$columns .= ($this->params->get('columns_md')) ? ' col-md-'.round(12 / $this->params->get('columns_md')) : '';
				
if($masonry){
	$doc->addScript(Uri::root(true) . '/templates/'.$template_name.'/js/ut_assets/isotope/isotope.pkgd.min.js' );
	$columns .= ' masonry-item';
}

$blog_class = ($this->params->get('ublog_style')) ? ' blog-'.$this->params->get('ublog_style') : '';
?>

<div class="ublog <?php echo $blog_class.' '.$this->pageclass_sfx; ?>" itemscope="" itemtype="http://schema.org/Blog">
	<?php if ($this->params->get('show_page_heading')) : ?>
		<div class="page-header">
			<h1><?php echo $this->escape($this->params->get('page_heading')); ?></h1>
		</div>
	<?php endif; ?>
	
	<?php echo $afterDisplayTitle; ?>

	<?php if (empty($this->lead_items) && empty($this->link_items) && empty($this->intro_items)) : ?>
		<?php if ($this->params->get('show_no_articles', 1)) : ?>
			<p><?php echo Text::_('COM_CONTENT_NO_ARTICLES'); ?></p>
		<?php endif; ?>
	<?php endif; ?>

	<?php $leadingcount = 0; ?>
	<?php if (!empty($this->lead_items)) : ?>
		<div class="article-list articles-leading">
			<?php foreach ($this->lead_items as &$item) : ?>
				<div class="article<?php echo $item->state == 0 ? ' system-unpublished' : null; ?>"
					itemprop="blogPost" itemscope itemtype="https://schema.org/BlogPosting">
					<?php
					$this->item = & $item;
					$this->item->leading = true;
					echo $this->loadTemplate('item');
					?>
				</div>
				<?php $leadingcount++; ?>
			<?php endforeach; ?>
		</div>
	<?php endif; ?>

	<?php
	$introcount = count($this->intro_items);
	$counter = 0;
	?>

	<?php if (!empty($this->intro_items)) : ?>
		<div class="article-list">
			<div class="row<?php echo ($masonry) ? ' masonry' : '';?>">
			<?php foreach ($this->intro_items as $key => &$item) : ?>
				<div class="<?php echo $columns; ?>">
					<div class="article <?php echo $item->state == 0 ? ' system-unpublished' : null; ?>"
						itemprop="blogPost" itemscope itemtype="https://schema.org/BlogPosting">
						<?php
						$this->item = & $item;
						echo $this->loadTemplate('item');
						?>
					</div>
					<?php $counter++; ?>
				</div>
			<?php endforeach; ?>
			</div>
		</div>
	<?php endif; ?>

	<?php if (($this->params->def('show_pagination', 1) == 1 || ($this->params->get('show_pagination') == 2)) && ($this->pagination->pagesTotal > 1)) : ?>
		<nav class="pagination-wrapper d-flex justify-content-center w-100">
			<?php echo $this->pagination->getPagesLinks(); ?>
		</nav>
	<?php endif; ?>
</div>
<?php if($masonry):?>
	<script>
	window.addEventListener("load", function() {
		var iso = new Isotope('.masonry', {
			// options
			itemSelector: '.masonry-item',
			percentPosition: true,
			masonry:{
				columnWidth:'.masonry-item'
			}
		});
	});
	</script>
<?php endif;?>
